@@ -76,6 +76,7 @@ use Perl6::Pod::To::XHTML::ProcessHeadings;
 use Perl6::Pod::To::XHTML::MakeHead;
 use Perl6::Pod::To::XHTML::MakeBody;
 use Perl6::Pod::Parser::Doformatted;
+use Perl6::Pod::Parser::Doallow;
 use XML::ExtOn('create_pipe');
 use base qw/Perl6::Pod::To::XML/;
 use constant POD_URI => 'http://perlcabal.org/syn/S26.html';
@@ -100,6 +101,7 @@ sub new {
       create_pipe( 'Perl6::Pod::To::XHTML::ProcessHeadings', $self->{out_put} );
     return create_pipe(
         'Perl6::Pod::Parser::Doformatted',
+        'Perl6::Pod::Parser::Doallow',
         'Perl6::Pod::Parser::ListLevels',
         'Perl6::Pod::Parser::AddHeadLevels',
         'Test::Filter', $self
